# -*- coding: utf-8 -*-
from __future__ import absolute_import
from __future__ import print_function


# from PIL import Image
import traceback
import tempfile
from sys import stdout
from os import remove
from os.path import isfile
from subprocess import check_call
from subprocess import Popen
from .utils import svg_dir


def convert_png_to_bmp(input_file, output_file=None):
    assert(input_file.endswith('.png'))
    if output_file is None:
        output_file = input_file[:-3] + 'bmp'
    print('input_file:', input_file, 'output_file:', output_file)
    args = [
        'magick',
        input_file,
        '-background', 'white',
        '-flatten',
        '-colors', '2',
        '-monochrome',
        '-threshold', '5%',
        output_file,
        ]
    print("args:", args)
    try:
        check_call(args)
    except OSError:
        args[0] = 'convert'
        check_call(args)


"""
def convert_png_to_bmp_2(input_file, output_file=None):
    assert(input_file.endswith('.png'))
    if output_file is None:
        output_file = input_file[:-3] + 'bmp'
    print('input_file:', input_file, 'output_file:', output_file)
    image = Image.open(input_file)
    x_size, y_size = image.size
    bg = Image.new("L", image.size, (255, 255, 255))
    bg.paste(image, image)
    bg1 = bg.quantize(2, method=2)
    bg1.save(output_file, compresssion="bmp_rle")
"""


def export_svg_to_png(input_file, output_file=None):
    assert(input_file.endswith('.svg'))
    if output_file is None:
        output_file = input_file[:-3] + 'png'
    args = [
        'inkscape',
        '-z',
        '-f', input_file,
        '-e', output_file,
        '--export-dpi=300',
        '--export-area-page',
        ]
    p = Popen(args, cwd=svg_dir)
    p.wait()


def export_svg_to_bmp(svg_file, bmp_file=None):
    assert(svg_file.endswith('.svg'))
    if bmp_file is None:
        bmp_file = svg_file[:-3] + 'bmp'
    with tempfile.NamedTemporaryFile(
        suffix='.png',
        delete=False
            ) as temp_file:
        png_file = temp_file.name
    try:
        export_svg_to_png(svg_file, png_file)
        convert_png_to_bmp(png_file, bmp_file)
    finally:
        if isfile(png_file):
            try:
                remove(png_file)
            except Exception:
                print('cannot remove temporary file:', png_file)
                traceback.print_exc(file=stdout)
